diff --git a/mbtrack2/impedance/impedance_model.py b/mbtrack2/impedance/impedance_model.py
index 4fc135240c20b19c36c7189325712bc8cdb1a720..f97d6256ab62f16fec7cf60944f25bc4f376fd09 100644
--- a/mbtrack2/impedance/impedance_model.py
+++ b/mbtrack2/impedance/impedance_model.py
@@ -445,6 +445,7 @@ class ImpedanceModel():
             
         if fmin >= 0:
             fmin = -1*fmax
+            double_sided_impedance(impedance)
             
         frequency = np.linspace(fmin, fmax, int(n_points))
         if max_overlap is False:
@@ -455,10 +456,6 @@ class ImpedanceModel():
         pmax = np.floor(fmax/self.ring.f0)
         pmin = np.floor(fmin/self.ring.f0)
         
-        if pmin >= 0:
-            double_sided_impedance(impedance)
-            pmin = -1*pmax
-        
         p = np.arange(pmin+1,pmax)    
         pf0 = p*self.ring.f0
         ReZ = np.real(impedance(pf0))
diff --git a/mbtrack2/impedance/wakefield.py b/mbtrack2/impedance/wakefield.py
index 5b6f92ab90e6885b1d0d147bb733068c391f079e..52807e6158c37441e0476e2a2b0423758e6f707b 100644
--- a/mbtrack2/impedance/wakefield.py
+++ b/mbtrack2/impedance/wakefield.py
@@ -873,7 +873,7 @@ class WakeField:
         Returns
         -------
         wake_sum : WakeField
-            WakeField with summed components..
+            WakeField with summed components.
 
         """
         if len(wakefields) == 1:
diff --git a/mbtrack2/utilities/read_impedance.py b/mbtrack2/utilities/read_impedance.py
index 9d0ac3038e79ef5428dbd956259381b51549344c..fa70cd1e0707cb7ccb19216786f768be92641104 100644
--- a/mbtrack2/utilities/read_impedance.py
+++ b/mbtrack2/utilities/read_impedance.py
@@ -93,8 +93,8 @@ def read_IW2D_folder(folder, suffix, select="WZ"):
     
     Parameters
     ----------
-    file : str
-        Path to the file to read.
+    folder : str
+        Path to the folder to read.
     suffix : str
         End of the name of each files. For example, in "Zlong_test.dat" the
         suffix should be "_test.dat".